#!/usr/bin/python
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.




# --------------------------------------------------------------------------
# these three variables can be specified here an omitted at the command line
# if specified in both places, the command line options have priority

vcluser = 'admin@Local' # log in to the VCL site with this user, must be in username@affiliation form
vclpass = 's1lv@dm1n' # password for vcluser
vclurl = 'https://vcl.ualberta.ca/vcl/index.php?mode=xmlrpccall' # URL of VCL site
# --------------------------------------------------------------------------

import xmlrpclib, sys, os, stat, re
from optparse import OptionParser

class VCLTransport(xmlrpclib.SafeTransport):
	##
	# Send a complete request, and parse the response.
	#
	# @param host Target host.
	# @param handler Target PRC handler.
	# @param request_body XML-RPC request body.
	# @param verbose Debugging flag.
	# @return Parsed response.

	def request(self, host, userid, passwd, handler, request_body, verbose=0):
		# issue XML-RPC request

		h = self.make_connection(host)
		if verbose:
			h.set_debuglevel(1)

		self.send_request(h, handler, request_body)
		h.putheader('X-APIVERSION', '2')
		h.putheader('X-User', userid)
		h.putheader('X-Pass', passwd)
		self.send_host(h, host)
		self.send_user_agent(h)
		self.send_content(h, request_body)

		errcode, errmsg, headers = h.getreply()

		if errcode != 200:
			raise ProtocolError(
				host + handler,
				errcode, errmsg,
				headers
				)

		self.verbose = verbose

		try:
			sock = h._conn.sock
		except AttributeError:
			sock = None

		try:
			resp = self._parse_response(h.getfile(), sock)
		except xmlrpclib.Fault, err:
			if(err.faultCode == 3):
				print "ERROR: Received '%s' error. The credentials you supplied to log in to the VCL site were not accepted." % (err.faultString)
			elif(err.faultCode == 4):
				print "ERROR: %s" % (err.faultString)
			elif(err.faultCode == 5):
				print "ERROR: Received '%s' error. The VCL site could not establish a connection with your authentication server." % (err.faultString)
			elif(err.faultCode == 6):
				print "ERROR: Received '%s' error. The VCL site could not determine a method to use to authenticate the supplied user." % (err.faultString)
			else:
				print "ERROR: Received '%s' error from VCL site." % (err.faultString)
			sys.exit(3)

		return resp

class VCLServerProxy(xmlrpclib.ServerProxy):
	__userid = ''
	__passwd = ''
	def __init__(self, uri, userid, passwd, transport=None, encoding=None,
				 verbose=0, allow_none=0, use_datetime=0):
		self.__userid = userid
		self.__passwd = passwd
		# establish a "logical" server connection

		# get the url
		import urllib
		type, uri = urllib.splittype(uri)
		if type not in ("http", "https"):
			raise IOError, "unsupported XML-RPC protocol"
		self.__host, self.__handler = urllib.splithost(uri)
		if not self.__handler:
			self.__handler = "/RPC2"

		if transport is None:
			transport = VCLTransport()
		self.__transport = transport

		self.__encoding = encoding
		self.__verbose = verbose
		self.__allow_none = allow_none

	def __request(self, methodname, params):
		# call a method on the remote server

		request = xmlrpclib.dumps(params, methodname, encoding=self.__encoding,
				  allow_none=self.__allow_none)

		response = self.__transport.request(
			self.__host,
			self.__userid,
			self.__passwd,
			self.__handler,
			request,
			verbose=self.__verbose
			)

		if len(response) == 1:
			response = response[0]

		return response

	def __getattr__(self, name):
		# magic method dispatcher
		return xmlrpclib._Method(self.__request, name)

	# note: to call a remote object with an non-standard name, use
	# result getattr(server, "strange-python-name")(args)

def getImages(vclurl, vcluser, vclpass):
	caller = VCLServerProxy(uri=vclurl, userid=vcluser, passwd=vclpass)
	rc = caller.XMLRPCgetImages()
	return rc

sys.exit(0)
