#!/bin/bash

IMAGE_FILE=convert_images.txt

if [ ! -e $IMAGE_FILE ]; then
	echo "No image file"
	exit 1
fi

for i in `cat $IMAGE_FILE | grep -v "^#"`; do

	if [ ! -e ./$i ]; then
		echo "ERROR: $i does not exist, exiting..."
		exit 1
	fi

	NAME=`echo $i | cut -f 4 -d "-"`-FIRSTBOOT

	if [ ! -e $i.qcow2 ]; then
		echo "INFO: converting $i to qcow2"
		if ! qemu-img convert -O qcow2 $i $i.qcow2; then
			echo "ERROR: Failed to convert $i to qcow2, exiting..."
			exit 1
		fi
	else
		echo "SKIP: $i.qcow2 already exists, skipping qemu-img convert..."
	fi


	echo "INFO: Importing $i.qcow2 into glance..."
	if ! glance add name="$NAME" disk_format=qcow2 container_format=bare < $i.qcow2; then
		echo "ERROR: Failed to import $i.qcow2 into glance, exiting..."
		exit 1
	fi
	echo "INFO: Done importing $i.qcow2 into glance"

done
