#!/bin/bash

# Add an entry into imagemeta

# drop and recreate the db

# Force drop of db
if ! mysqladmin -f drop vcl > /dev/null; then
	echo "ERROR: Failed to drop vcl db, exiting..."
	exit 1
fi

echo "INFO: Dropped vcl database..."

if ! mysqladmin create vcl; then
	echo "ERROR: Failed to create vcl db, exiting..."
	exit 1
fi

echo "INFO: Created vcl database..."

if ! mysql vcl < vcl.dump.wed_dec_5; then
	echo "ERROR: Failed to import db backup, exiting..."
	exit 1
fi

echo "INFO: Restored vcl database from sqldump..."

for i in `cat finished_images.txt  |grep -v "^#"`; do

	IMAGE_NAME=$(echo $i | cut -f 2 -d ",")
	IMAGE_OS_ID=$(echo $i | cut -f 1 -d ",")
	IMAGE_OS_FLAVOR=$(echo $i | cut -f 3 -d ",")

	echo "INFO: image name is $IMAGE_NAME and image openstack id is $IMAGE_OS_ID"

	# create a new imagemeta entry
	if ! mysql -u root -ss -e "use vcl; insert into imagemeta (checkuser, subimages, sysprep, rootaccess) values (1,0,1,1);"; then
		echo "ERROR: mysql insert into imagemeta failed, exiting..."
		exit 1
	fi

	# Get the id of that entry
	# -ss says quiet, no header names that kinda thing
	image_metaid=$(mysql -ss -u root -e "use vcl; select id from imagemeta order by id desc limit 1;")

	if [ -z "$image_metaid" ]; then
		echo "image_metaid failed, exiting..."
		exit 1
	fi

	# create the image entry
	# todo -- SIZE?
	if ! mysql -u root -ss -e "use vcl; insert into image ( name, prettyname, ownerid, imagetypeid, platformid, OSid, imagemetaid, minram, minprocnumber, minprocspeed, minnetwork, maxconcurrent, reloadtime, deleted, test, lastupdate, forcheckout, maxinitialtime, project, size, architecture, description) VALUES ('$IMAGE_NAME', '$IMAGE_NAME', 1, 1, 1, 46, 1, 0, 1, 0, 10, NULL, 10, 0, 0, NULL, 1, 0, 'vcl', 1450, 'x86_64', '$IMAGE_NAME');"; then
		echo "ERROR: Insert into image failed, exiting..."
		exit 1
	fi

	# Get the id of the iamge we just created...
	image_id=$(mysql -ss -u root -e "use vcl; select id from image where prettyname = '$IMAGE_NAME'")

	# create an image revision for that image
	if ! mysql -u root -ss -e "use vcl; insert into imagerevision (imageid, revision, userid, datecreated, deleted, production, imagename, autocaptured) values ($image_id, 0, 1, '2012-10-24 22:40:13', 0, 1, '$IMAGE_NAME', 0);"; then
		echo "ERROR: Insert into imagerevision failed, exiting..."
		exit 1
	fi

	if ! mysql -u root -ss -e "use vcl; insert into resource (resourcetypeid, subid) values (13, $image_id);"; then
		echo "insert into resource failed, exiting..."
		exit 1
	fi

 	if ! mysql -u root -ss -e "use vcl; insert into openstackImageNameMap (openstackimagename, vclimagename, flavor) values ('$IMAGE_OS_ID-v', '$IMAGE_NAME', $IMAGE_OS_FLAVOR);"; then
		echo "ERROR: insert into openstackImageNameMap failed, exiting..."
		exit 1
	fi

	echo "done importing image $IMAGE_NAME"

done
